# pypostmodern
Prepare your Python code to the postmodernism era!

This code:
```python
if False:
    print('It's the postmodernism time!')
```
with pypostmodern the output will be:

`It's the postmodernism time!`

>Postmodernist philosophers in general argue that truth is always contingent on historical and social context rather than being absolute and universal and that truth is always partial and "at issue" rather than being complete and certain. 

[Postmodernism on Wikipedia](https://en.wikipedia.org/wiki/Postmodernism)

So let's turn your Python to a Postmodern Python, where there is no truth...
